==> estateplat-common-1.2.4-20220617.062024-1045-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxTcJcptDyqk.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;

@Table(name = "gx_tc_jcpt_dyqk")
public class GxTcJcptDyqk {
    @Id
    private String ywid;
    private String bjbh;
    private Double bdbzqse;
    private Double bdcpgjg;
    private String dbfw;
    private String dyfs;
    private String dyhtbh;
    private String dysw;
    private String zqr;
    private String zwlxjssj;
    private String zwlxqssj;
    private String zwr;
    private String sfxzzr;

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getBjbh() {
        return bjbh;
    }

    public void setBjbh(String bjbh) {
        this.bjbh = bjbh;
    }

    public Double getBdbzqse() {
        return bdbzqse;
    }

    public void setBdbzqse(Double bdbzqse) {
        this.bdbzqse = bdbzqse;
    }

    public Double getBdcpgjg() {
        return bdcpgjg;
    }

    public void setBdcpgjg(Double bdcpgjg) {
        this.bdcpgjg = bdcpgjg;
    }

    public String getDbfw() {
        return dbfw;
    }

    public void setDbfw(String dbfw) {
        this.dbfw = dbfw;
    }

    public String getDyfs() {
        return dyfs;
    }

    public void setDyfs(String dyfs) {
        this.dyfs = dyfs;
    }

    public String getDyhtbh() {
        return dyhtbh;
    }

    public void setDyhtbh(String dyhtbh) {
        this.dyhtbh = dyhtbh;
    }

    public String getDysw() {
        return dysw;
    }

    public void setDysw(String dysw) {
        this.dysw = dysw;
    }

    public String getZqr() {
        return zqr;
    }

    public void setZqr(String zqr) {
        this.zqr = zqr;
    }

    public String getZwlxjssj() {
        return zwlxjssj;
    }

    public void setZwlxjssj(String zwlxjssj) {
        this.zwlxjssj = zwlxjssj;
    }

    public String getZwlxqssj() {
        return zwlxqssj;
    }

    public void setZwlxqssj(String zwlxqssj) {
        this.zwlxqssj = zwlxqssj;
    }

    public String getZwr() {
        return zwr;
    }

    public void setZwr(String zwr) {
        this.zwr = zwr;
    }

    public String getSfxzzr() {
        return sfxzzr;
    }

    public void setSfxzzr(String sfxzzr) {
        this.sfxzzr = sfxzzr;
    }
}

==> estateplat-common-1.2.4-20221012.030624-1101-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxTcJcptDyqk.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;

@Table(name = "gx_tc_jcpt_dyqk")
public class GxTcJcptDyqk {
    @Id
    private String ywid;
    private String bjbh;
    private Double bdbzqse;
    private Double bdcpgjg;
    private String dbfw;
    private String dyfs;
    private String dyhtbh;
    private String dysw;
    private String zqr;
    private String zwlxjssj;
    private String zwlxqssj;
    private String zwr;
    private String sfxzzr;
    private String sfdzzs;
    private String lzfs;
    private String bz;
    private String jfqk;
    private String jkm;

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getBjbh() {
        return bjbh;
    }

    public void setBjbh(String bjbh) {
        this.bjbh = bjbh;
    }

    public Double getBdbzqse() {
        return bdbzqse;
    }

    public void setBdbzqse(Double bdbzqse) {
        this.bdbzqse = bdbzqse;
    }

    public Double getBdcpgjg() {
        return bdcpgjg;
    }

    public void setBdcpgjg(Double bdcpgjg) {
        this.bdcpgjg = bdcpgjg;
    }

    public String getDbfw() {
        return dbfw;
    }

    public void setDbfw(String dbfw) {
        this.dbfw = dbfw;
    }

    public String getDyfs() {
        return dyfs;
    }

    public void setDyfs(String dyfs) {
        this.dyfs = dyfs;
    }

    public String getDyhtbh() {
        return dyhtbh;
    }

    public void setDyhtbh(String dyhtbh) {
        this.dyhtbh = dyhtbh;
    }

    public String getDysw() {
        return dysw;
    }

    public void setDysw(String dysw) {
        this.dysw = dysw;
    }

    public String getZqr() {
        return zqr;
    }

    public void setZqr(String zqr) {
        this.zqr = zqr;
    }

    public String getZwlxjssj() {
        return zwlxjssj;
    }

    public void setZwlxjssj(String zwlxjssj) {
        this.zwlxjssj = zwlxjssj;
    }

    public String getZwlxqssj() {
        return zwlxqssj;
    }

    public void setZwlxqssj(String zwlxqssj) {
        this.zwlxqssj = zwlxqssj;
    }

    public String getZwr() {
        return zwr;
    }

    public void setZwr(String zwr) {
        this.zwr = zwr;
    }

    public String getSfxzzr() {
        return sfxzzr;
    }

    public void setSfxzzr(String sfxzzr) {
        this.sfxzzr = sfxzzr;
    }

    public String getSfdzzs() {
        return sfdzzs;
    }

    public void setSfdzzs(String sfdzzs) {
        this.sfdzzs = sfdzzs;
    }

    public String getLzfs() {
        return lzfs;
    }

    public void setLzfs(String lzfs) {
        this.lzfs = lzfs;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getJfqk() {
        return jfqk;
    }

    public void setJfqk(String jfqk) {
        this.jfqk = jfqk;
    }

    public String getJkm() {
        return jkm;
    }

    public void setJkm(String jkm) {
        this.jkm = jkm;
    }
}
